@@ -66,17 +66,17 @@ namespace giac {
     }
     return a.islesscomplexthan(b);
   }
-  typedef map<gen,gen,comparegen > rootmap;
-  static rootmap & symbolic_rootof_list(){
+
+  rootmap & symbolic_rootof_list(){
     static rootmap * ans= new rootmap;
     return *ans;
   }
-  static rootmap & proot_list(){
+  rootmap & proot_list(){
     static rootmap * ans= new rootmap;
     return *ans;
   }
 
-  static rootmap & galoisconj_list(){
+  rootmap & galoisconj_list(){
     static rootmap * ans= new rootmap;
     return *ans;
   }
@@ -1134,8 +1134,10 @@ namespace giac {
       return rootof(makesequence(makevecteur(1,0),e),contextptr);
     if (has_num_coeff(e))
       return approx_rootof(e,contextptr);
-    if (!lop(lvar(e),at_pow).empty())
-      return gensizeerr(gettext("Algebraic extensions not allowed in a rootof"));
+    if (!lop(lvar(e),at_pow).empty()){
+      *logptr(contextptr) << gettext("Algebraic extensions not allowed in a rootof");
+      return approx_rootof(e,contextptr);
+    }
     // should call factor before returning unevaluated rootof
     if (e.type==_VECT && e._VECTptr->size()==2 && e._VECTptr->back().type==_VECT){
       vecteur v2=*e._VECTptr->back()._VECTptr;
