@@ -31,7 +31,7 @@
 #if defined VISUALC || defined BESTA_OS 
 typedef long pid_t;
 #else // VISUALC
-#if !defined(__MINGW_H) && !defined(NSPIRE) && !defined(__ANDROID__) && !defined(NSPIRE_NEWLIB) && !defined(OSX) && !defined(IOS) && !defined(FIR_LINUX)
+#if !defined(__MINGW_H) && !defined(NSPIRE) && !defined(__ANDROID__) && !defined(NSPIRE_NEWLIB) && !defined(OSX) && !defined(IOS) && !defined(OSXIOS) && !defined(FIR_LINUX)
 #include "wince_replacements.h"
 #endif
 #ifdef __MINGW_H
@@ -776,6 +776,7 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   double & epsilon(GIAC_CONTEXT);
   void epsilon(double c,GIAC_CONTEXT);
   double & proba_epsilon(GIAC_CONTEXT);
+  extern double min_proba_time; // in seconds, minimal time for proba early termination
 
 #ifdef NSPIRE
   nio::console * logptr(GIAC_CONTEXT);
@@ -969,6 +970,8 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   void gprintf(unsigned special,const std::string & format,const vecteur & v,GIAC_CONTEXT);
   void gprintf(unsigned special,const std::string & format,const vecteur & v,int step_info,GIAC_CONTEXT);
   gen make_symbolic(const gen & op,const gen & args);
+  // optional, call it just before exiting
+  int release_globals();
   
 #ifndef NO_NAMESPACE_GIAC
 } // namespace giac
